- Inheritance
-
- Object
- PlatformInterface
- AttributionSdkCore
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enableAttributionListener()
→ void
-
-
enableIpListener()
→ void
-
-
enableLog()
→ void
-
-
getAttributionInfo()
→ Future<Map<String, dynamic>?>
-
-
initSdk(String appCode, String devToken, String appleStoreId, {String? metaAppId, String? appsFlyerAppId, String? appsFlyerDevKey})
→ void
-
-
launch()
→ void
-
-
logCustomEvent(String eventName, {Map<String, dynamic>? customParams, Map<String, dynamic>? standardContent})
→ void
-
-
logEvent(String eventType, [])
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setAccountId(String accountId)
→ void
-
-
setClipboardInfo(String clipboardInfo)
→ void
-
-
setDeviceId(String deviceId)
→ void
-
-
setGaid(String gaid)
→ void
-
-
setPackageSource(String packageSource)
→ void
-
-
setSdkCallback(SdkCallback? callback)
→ void
-
-
setUserInfo(Map<String, dynamic> userInfo)
→ void
-
-
setWaitForAccountId(bool waitForAccountId)
→ void
-
-
setWaitForDeviceId(bool waitForDeviceId)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
trackAppReEngagement(String deeplinkInfo)
→ void
-